@@ -5,7 +5,7 @@
  *  This module implements expression functions that
  *  query and get state information from AutoGen data.
  *
- *  Time-stamp:        "2010-07-11 12:57:08 bkorb"
+ *  Time-stamp:        "2010-11-08 14:45:32 bkorb"
  *
  *  This file is part of AutoGen.
  *  AutoGen Copyright (c) 1992-2010 by Bruce Korb - all rights reserved
@@ -45,16 +45,19 @@
 
 /* = = = START-STATIC-FORWARD = = = */
 static int
-entry_length(char* pzName);
+entry_length(char* name);
 
 static int
-count_entries(char* pzName);
+count_entries(char* name);
 
 static SCM
 find_entry_value(SCM op, SCM obj, SCM test);
 
 static ver_type_t
 str2int_ver(char* pz);
+
+static SCM
+do_tpl_file_line(int line_delta, char const * fmt);
 /* = = = END-STATIC-FORWARD = = = */
 
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
@@ -62,9 +65,9 @@ str2int_ver(char* pz);
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
 static int
-entry_length(char* pzName)
+entry_length(char* name)
 {
-    tDefEntry**  papDefs = findEntryList(pzName);
+    tDefEntry**  papDefs = findEntryList(name);
     int          res     = 0;
 
     if (papDefs == NULL)
@@ -84,9 +87,9 @@ entry_length(char* pzName)
 
 
 static int
-count_entries(char* pzName)
+count_entries(char* name)
 {
-    tDefEntry**  papDefs = findEntryList(pzName);
+    tDefEntry**  papDefs = findEntryList(name);
     int          res     = 0;
 
     if (papDefs == NULL)
@@ -107,22 +110,25 @@ count_entries(char* pzName)
 static SCM
 find_entry_value(SCM op, SCM obj, SCM test)
 {
+    static char const zFailed[] = "failed\n";
+    static char const zSucc[]   = "SUCCESS\n";
+
     ag_bool     isIndexed;
     tDefEntry*  pE;
-    tSCC        zFailed[] = "failed\n";
-    tSCC        zSucc[]   = "SUCCESS\n";
     char*       pzField;
 
-    char * pzName = ag_scm2zchars(obj, "find name");
+    {
+        char * name = ag_scm2zchars(obj, "find name");
 
-    if (OPT_VALUE_TRACE >= TRACE_EXPRESSIONS)
-        fprintf(pfTrace, " in \"%s\" -- ", pzName);
+        if (OPT_VALUE_TRACE >= TRACE_EXPRESSIONS)
+            fprintf(pfTrace, " in \"%s\" -- ", name);
 
-    pzField = strchr(pzName, '.');
-    if (pzField != NULL)
-        *(pzField++) = NUL;
+        pzField = strchr(name, name_sep_ch);
+        if (pzField != NULL)
+            *(pzField++) = NUL;
 
-    pE = findDefEntry(pzName, &isIndexed);
+        pE = findDefEntry(name, &isIndexed);
+    }
 
     /*
      *  No such entry?  return FALSE
@@ -175,7 +181,7 @@ find_entry_value(SCM op, SCM obj, SCM test)
     /*
      *  Search the members for what we want.
      */
-    pzField[-1] = '.';
+    pzField[-1] = name_sep_ch;
     {
         SCM field   = AG_SCM_STR02SCM(pzField);
         SCM result;
@@ -715,6 +721,28 @@ ag_scm_tpl_file(SCM full)
     return AG_SCM_STR02SCM((char*)(void*)pzTemplFileName);
 }
 
+/**
+ * guts of the template file/line functions
+ */
+static SCM
+do_tpl_file_line(int line_delta, char const * fmt)
+{
+    char * buf;
+
+    {
+        size_t sz = strlen(fmt) + strlen(pCurTemplate->pzTplFile) + 24;
+        buf = ag_scribble(sz);
+    }
+
+    {
+        void * args[2];
+        args[0] = (void*)pCurTemplate->pzTplFile;
+        args[1] = (void*)((long)pCurMacro->lineNo + line_delta);
+        sprintfv(buf, fmt, (snv_constpointer*)args);
+    }
+
+    return AG_SCM_STR02SCM(buf);
+}
 
 /*=gfunc tpl_file_line
  *
@@ -723,7 +751,6 @@ ag_scm_tpl_file(SCM full)
  * exparg: msg-fmt, formatting for line message, optional
  *
  * doc:
- *
  *  Returns the file and line number of the current template macro using
  *  either the default format, "from %s line %d", or else the format you
  *  supply.  For example, if you want to insert a "C" language file-line
@@ -735,43 +762,42 @@ ag_scm_tpl_file(SCM full)
  *  @end example
  *
  *  It is also safe to use the formatting string, "%2$d".  AutoGen uses
- *  an argument vector version of printf: @xref{snprintfv}.
+ *  an argument vector version of printf: @xref{snprintfv},
+ *  and it does not need to know the types of each argument in order to
+ *  skip forward to the second argument.
 =*/
 SCM
 ag_scm_tpl_file_line(SCM fmt)
 {
-    char    zScribble[ 1024 ];
-    tSCC    zFmt[] = "from %s line %d";
-    char const * pzFmt = zFmt;
-    char*   pz;
+    char const * pzFmt = "from %s line %d";
 
     if (AG_SCM_STRING_P(fmt))
         pzFmt = ag_scm2zchars(fmt, "file/line format");
 
-    {
-        size_t  maxlen = strlen(pCurTemplate->pzTplFile)
-                       + strlen(pzFmt) + 4 * sizeof(int);
-        if (maxlen >= sizeof(zScribble))
-             pz = (char*)AGALOC(maxlen, "file-line buffer");
-        else pz = zScribble;
-    }
-
-    {
-        void* args[2];
-        args[0] = (void*)pCurTemplate->pzTplFile;
-        args[1] = (void*)(long)pCurMacro->lineNo;
-        sprintfv(pz, pzFmt, (snv_constpointer*)args);
-    }
-
-    {
-        SCM res = AG_SCM_STR02SCM(pz);
-        if (pz != zScribble)
-            AGFREE((void*)pz);
-
-        return res;
-    }
+    return do_tpl_file_line(0, pzFmt);
 }
 
+/*=gfunc tpl_file_next_line
+ *
+ * what:   get the template file plus next line number
+ *
+ * exparg: msg-fmt, formatting for line message, optional
+ *
+ * doc:
+ *  This is almost the same as @xref{SCM tpl-file-line}, except that
+ *  the line referenced is the next line, per C compiler conventions, and
+ *  consequently defaults to the format:  # <line-no+1> "<file-name>"
+=*/
+SCM
+ag_scm_tpl_file_next_line(SCM fmt)
+{
+    char const * pzFmt = "# %2$d \"%1$s\"";
+
+    if (AG_SCM_STRING_P(fmt))
+        pzFmt = ag_scm2zchars(fmt, "file/line format");
+
+    return do_tpl_file_line(1, pzFmt);
+}
 
 /*=gfunc def_file_line
  *
@@ -781,7 +807,6 @@ ag_scm_tpl_file_line(SCM fmt)
  * exparg: msg-fmt, formatting for line message, optional
  *
  * doc:
- *
  *  Returns the file and line number of a AutoGen defined value, using
  *  either the default format, "from %s line %d", or else the format you
  *  supply.  For example, if you want to insert a "C" language file-line
