@@ -1,6 +1,7 @@
-/*
- *  $Id: f1650b45a91ec95af830ff76041cc4f0048e60f0 $
- *  Time-stamp:      "2010-04-24 12:57:03 bkorb"
+/**
+ * \file configfile.c
+ *
+ *  Time-stamp:      "2010-11-07 14:43:09 bkorb"
  *
  *  configuration/rc/ini file handling.
  *
@@ -25,59 +26,45 @@
  *  66a5cedaf62c4b2637025f049f9b826f pkg/libopts/COPYING.mbsd
  */
 
+static void
+set_usage_flags(tOptions * opts, char const * flg_txt);
+
 /* = = = START-STATIC-FORWARD = = = */
 static void
-filePreset(
-    tOptions*     pOpts,
-    char const*   pzFileName,
-    int           direction );
+file_preset(tOptions * opts, char const * fname, int dir);
 
 static char*
-handleComment( char* pzText );
+handle_comment(char* pzText);
+
+static char *
+handle_cfg(tOptions * pOpts, tOptState * pOS, char * pzText, int dir);
+
+static char *
+handle_directive(tOptions * pOpts, char * pzText);
+
+static char *
+aoflags_directive(tOptions * pOpts, char * pzText);
+
+static char *
+program_directive(tOptions * pOpts, char * pzText);
+
+static char *
+handle_section(tOptions * pOpts, char * pzText);
+
+static char *
+handle_struct(tOptions * pOpts, tOptState * pOS, char * pzText, int dir);
 
 static char*
-handleConfig(
-    tOptions*     pOpts,
-    tOptState*    pOS,
-    char*         pzText,
-    int           direction );
+parse_keyword(tOptions * pOpts, char * pzText, tOptionValue * pType);
 
 static char*
-handleDirective(
-    tOptions*     pOpts,
-    char*         pzText );
+parse_set_mem(tOptions * pOpts, char * pzText, tOptionValue * pType);
 
-static char*
-handleProgramSection(
-    tOptions*     pOpts,
-    char*         pzText );
+static char *
+parse_value(char * pzText, tOptionValue * pType);
 
-static char*
-handleStructure(
-    tOptions*     pOpts,
-    tOptState*    pOS,
-    char*         pzText,
-    int           direction );
-
-static char*
-parseKeyWordType(
-    tOptions*     pOpts,
-    char*         pzText,
-    tOptionValue* pType );
-
-static char*
-parseSetMemType(
-    tOptions*     pOpts,
-    char*         pzText,
-    tOptionValue* pType );
-
-static char*
-parseValueType(
-    char*         pzText,
-    tOptionValue* pType );
-
-static char*
-skipUnknown( char* pzText );
+static char *
+skip_unkn(char* pzText);
 /* = = = END-STATIC-FORWARD = = = */
 
 
@@ -112,14 +99,14 @@ skipUnknown( char* pzText );
  *  @end itemize
 =*/
 const tOptionValue*
-configFileLoad( char const* pzFile )
+configFileLoad(char const* pzFile)
 {
     tmap_info_t   cfgfile;
     tOptionValue* pRes = NULL;
     tOptionLoadMode save_mode = option_load_mode;
 
     char* pzText =
-        text_mmap( pzFile, PROT_READ, MAP_PRIVATE, &cfgfile );
+        text_mmap(pzFile, PROT_READ, MAP_PRIVATE, &cfgfile);
 
     if (TEXT_MMAP_FAILED_ADDR(pzText))
         return NULL; /* errno is set */
@@ -129,10 +116,10 @@ configFileLoad( char const* pzFile )
 
     if (pRes == NULL) {
         int err = errno;
-        text_munmap( &cfgfile );
+        text_munmap(&cfgfile);
         errno = err;
     } else
-        text_munmap( &cfgfile );
+        text_munmap(&cfgfile);
 
     option_load_mode = save_mode;
     return pRes;
@@ -164,8 +151,8 @@ configFileLoad( char const* pzFile )
  *  @end itemize
 =*/
 const tOptionValue*
-optionFindValue( const tOptDesc* pOptDesc,
-                 char const* pzName, char const* pzVal )
+optionFindValue(const tOptDesc* pOptDesc, char const* pzName,
+                char const* pzVal)
 {
     const tOptionValue* pRes = NULL;
 
@@ -195,7 +182,7 @@ optionFindValue( const tOptDesc* pOptDesc,
 
         while (--ct >= 0) {
             const tOptionValue* pOV = *(ppOV++);
-            const tOptionValue* pRV = optionGetValue( pOV, pzName );
+            const tOptionValue* pRV = optionGetValue(pOV, pzName);
 
             if (pRV == NULL)
                 continue;
@@ -239,9 +226,9 @@ optionFindValue( const tOptDesc* pOptDesc,
  *  @code{ENOENT} - no entry matched the given name.
  *  @end itemize
 =*/
-const tOptionValue*
-optionFindNextValue( const tOptDesc* pOptDesc, const tOptionValue* pPrevVal,
-                 char const* pzName, char const* pzVal )
+tOptionValue const *
+optionFindNextValue(const tOptDesc * pOptDesc, const tOptionValue * pPrevVal,
+                    char const * pzName, char const * pzVal)
 {
     int foundOldVal = 0;
     tOptionValue* pRes = NULL;
@@ -308,7 +295,7 @@ optionFindNextValue( const tOptDesc* pOptDesc, const tOptionValue* pPrevVal,
  *  @end itemize
 =*/
 const tOptionValue*
-optionGetValue( const tOptionValue* pOld, char const* pzValName )
+optionGetValue(const tOptionValue* pOld, char const* pzValName)
 {
     tArgList*     pAL;
     tOptionValue* pRes = NULL;
@@ -329,7 +316,7 @@ optionGetValue( const tOptionValue* pOld, char const* pzValName )
 
         else do {
             tOptionValue* pOV = *(papOV++);
-            if (strcmp( pOV->pzName, pzValName ) == 0) {
+            if (strcmp(pOV->pzName, pzValName) == 0) {
                 pRes = pOV;
                 break;
             }
@@ -404,28 +391,24 @@ optionNextValue(tOptionValue const * pOVList,tOptionValue const * pOldOV )
 }
 
 
-/*  filePreset
- *
+/**
  *  Load a file containing presetting information (a configuration file).
  */
 static void
-filePreset(
-    tOptions*     pOpts,
-    char const*   pzFileName,
-    int           direction )
+file_preset(tOptions * opts, char const * fname, int dir)
 {
     tmap_info_t   cfgfile;
     tOptState     optst = OPTSTATE_INITIALIZER(PRESET);
     tAoUL         st_flags = optst.flags;
-    char*         pzFileText =
-        text_mmap( pzFileName, PROT_READ|PROT_WRITE, MAP_PRIVATE, &cfgfile );
+    char *        ftext =
+        text_mmap(fname, PROT_READ|PROT_WRITE, MAP_PRIVATE, &cfgfile);
 
-    if (TEXT_MMAP_FAILED_ADDR(pzFileText))
+    if (TEXT_MMAP_FAILED_ADDR(ftext))
         return;
 
-    if (direction == DIRECTION_CALLED) {
+    if (dir == DIRECTION_CALLED) {
         st_flags = OPTST_DEFINED;
-        direction   = DIRECTION_PROCESS;
+        dir   = DIRECTION_PROCESS;
     }
 
     /*
@@ -434,34 +417,33 @@ filePreset(
      *  If this is called via "optionFileLoad", then the bit is not set
      *  and we consider stuff set herein to be "set" by the client program.
      */
-    if ((pOpts->fOptSet & OPTPROC_PRESETTING) == 0)
+    if ((opts->fOptSet & OPTPROC_PRESETTING) == 0)
         st_flags = OPTST_SET;
 
     do  {
         optst.flags = st_flags;
-        while (IS_WHITESPACE_CHAR(*pzFileText))  pzFileText++;
+        while (IS_WHITESPACE_CHAR(*ftext))  ftext++;
 
-        if (IS_VAR_FIRST_CHAR(*pzFileText)) {
-            pzFileText = handleConfig(pOpts, &optst, pzFileText, direction);
+        if (IS_VAR_FIRST_CHAR(*ftext)) {
+            ftext = handle_cfg(opts, &optst, ftext, dir);
 
-        } else switch (*pzFileText) {
+        } else switch (*ftext) {
         case '<':
-            if (IS_VAR_FIRST_CHAR(pzFileText[1]))
-                pzFileText =
-                    handleStructure(pOpts, &optst, pzFileText, direction);
+            if (IS_VAR_FIRST_CHAR(ftext[1]))
+                ftext = handle_struct(opts, &optst, ftext, dir);
 
-            else switch (pzFileText[1]) {
+            else switch (ftext[1]) {
             case '?':
-                pzFileText = handleDirective( pOpts, pzFileText );
+                ftext = handle_directive(opts, ftext);
                 break;
 
             case '!':
-                pzFileText = handleComment( pzFileText );
+                ftext = handle_comment(ftext);
                 break;
 
             case '/':
-                pzFileText = strchr( pzFileText+2, '>' );
-                if (pzFileText++ != NULL)
+                ftext = strchr(ftext + 2, '>');
+                if (ftext++ != NULL)
                     break;
 
             default:
@@ -470,55 +452,49 @@ filePreset(
             break;
 
         case '[':
-            pzFileText = handleProgramSection( pOpts, pzFileText );
+            ftext = handle_section(opts, ftext);
             break;
 
         case '#':
-            pzFileText = strchr( pzFileText+1, '\n' );
+            ftext = strchr(ftext + 1, '\n');
             break;
 
         default:
             goto all_done; /* invalid format */
         }
-    } while (pzFileText != NULL);
+    } while (ftext != NULL);
 
- all_done:
-    text_munmap( &cfgfile );
+all_done:
+    text_munmap(&cfgfile);
 }
 
 
-/*  handleComment
- *
+/**
  *  "pzText" points to a "<!" sequence.
  *  Theoretically, we should ensure that it begins with "<!--",
  *  but actually I don't care that much.  It ends with "-->".
  */
 static char*
-handleComment( char* pzText )
+handle_comment(char* pzText)
 {
-    char* pz = strstr( pzText, "-->" );
+    char* pz = strstr(pzText, "-->");
     if (pz != NULL)
         pz += 3;
     return pz;
 }
 
 
-/*  handleConfig
- *
+/**
  *  "pzText" points to the start of some value name.
  *  The end of the entry is the end of the line that is not preceded by
  *  a backslash escape character.  The string value is always processed
  *  in "cooked" mode.
  */
-static char*
-handleConfig(
-    tOptions*     pOpts,
-    tOptState*    pOS,
-    char*         pzText,
-    int           direction )
+static char *
+handle_cfg(tOptions * pOpts, tOptState * pOS, char * pzText, int dir)
 {
     char* pzName = pzText++;
-    char* pzEnd  = strchr( pzText, '\n' );
+    char* pzEnd  = strchr(pzText, '\n');
 
     if (pzEnd == NULL)
         return pzText + strlen(pzText);
@@ -528,7 +504,7 @@ handleConfig(
     if (pzText > pzEnd) {
     name_only:
         *pzEnd++ = NUL;
-        loadOptionLine( pOpts, pOS, pzName, direction, OPTION_LOAD_UNCOOKED );
+        loadOptionLine(pOpts, pOS, pzName, dir, OPTION_LOAD_UNCOOKED);
         return pzEnd;
     }
 
@@ -584,100 +560,161 @@ handleConfig(
      *  "pzName" points to what looks like text for one option/configurable.
      *  It is NUL terminated.  Process it.
      */
-    loadOptionLine( pOpts, pOS, pzName, direction, OPTION_LOAD_UNCOOKED );
+    loadOptionLine(pOpts, pOS, pzName, dir, OPTION_LOAD_UNCOOKED);
 
     return pzEnd;
 }
 
 
-/*  handleDirective
- *
+/**
  *  "pzText" points to a "<?" sequence.
- *  For the moment, we only handle "<?program" directives.
+ *  We handle "<?program" and "<?auto-options" directives.
+ *  All others are treated as comments.
  */
-static char*
-handleDirective(
-    tOptions*     pOpts,
-    char*         pzText )
+static char *
+handle_directive(tOptions * pOpts, char * pzText)
 {
-    char   ztitle[32] = "<?";
-    size_t title_len = strlen( zProg );
-    size_t name_len;
+#   define DIRECTIVE_TABLE                      \
+    _dt_(zCfgProg,     program_directive)       \
+    _dt_(zCfgAO_Flags, aoflags_directive)
 
-    if (  (strncmp( pzText+2, zProg, title_len ) != 0)
-       || (! IS_WHITESPACE_CHAR(pzText[title_len+2])) )  {
-        pzText = strchr( pzText+2, '>' );
-        if (pzText != NULL)
-            pzText++;
-        return pzText;
+    typedef char * (directive_func_t)(tOptions *, char *);
+#   define _dt_(_s, _fn) _fn,
+    static directive_func_t * dir_disp[] = {
+        DIRECTIVE_TABLE
+    };
+#   undef  _dt_
+
+#   define _dt_(_s, _fn) 1 +
+    static int  const   dir_ct  = DIRECTIVE_TABLE 0;
+    static char const * dir_names[DIRECTIVE_TABLE 0];
+#   undef _dt_
+
+    int    ix;
+
+    if (dir_names[0] == NULL) {
+        ix = 0;
+#   define _dt_(_s, _fn) dir_names[ix++] = _s;
+        DIRECTIVE_TABLE;
+#   undef _dt_
     }
 
-    name_len = strlen( pOpts->pzProgName );
-    strcpy( ztitle+2, zProg );
-    title_len += 2;
+    for (ix = 0; ix < dir_ct; ix++) {
+        size_t len = strlen(dir_names[ix]);
+        if (  (strncmp(pzText + 2, dir_names[ix], len) == 0)
+           && (! IS_VALUE_NAME_CHAR(pzText[len+2])) )
+            return dir_disp[ix](pOpts, pzText + len + 2);
+    }
+
+    /*
+     *  We don't know what this is.  Skip it.
+     */
+    pzText = strchr(pzText+2, '>');
+    if (pzText != NULL)
+        pzText++;
+    return pzText;
+}
+
+/**
+ *  handle AutoOpts mode flags
+ */
+static char *
+aoflags_directive(tOptions * pOpts, char * pzText)
+{
+    char * pz = pzText;
+
+    while (IS_WHITESPACE_CHAR(*++pz))  ;
+    pzText = strchr(pz, '>');
+    if (pzText != NULL) {
+
+        size_t len  = pzText - pz;
+        char * ftxt = AGALOC(len + 1, "aoflags");
+
+        memcpy(ftxt, pz, len);
+        ftxt[len] = NUL;
+        set_usage_flags(pOpts, ftxt);
+        AGFREE(ftxt);
+
+        pzText++;
+    }
+
+    return pzText;
+}
+
+/**
+ * handle program segmentation of config file.
+ */
+static char *
+program_directive(tOptions * pOpts, char * pzText)
+{
+    char * ttl;
+    size_t ttl_len  = asprintf(&ttl, "<?%s", zCfgProg);
+    size_t name_len = strlen(pOpts->pzProgName);
+
+    (void) ttl_len;
 
     do  {
-        pzText += title_len;
+        while (IS_WHITESPACE_CHAR(*++pzText))  ;
 
-        if (IS_WHITESPACE_CHAR(*pzText)) {
-            while (IS_WHITESPACE_CHAR(*++pzText))  ;
-            if (  (strneqvcmp( pzText, pOpts->pzProgName, (int)name_len) == 0)
-               && (pzText[name_len] == '>'))  {
-                pzText += name_len + 1;
-                break;
-            }
+        if (  (strneqvcmp(pzText, pOpts->pzProgName, (int)name_len) == 0)
+           && (IS_END_XML_TOKEN_CHAR(pzText[name_len])) ) {
+            pzText += name_len;
+            break;
         }
 
-        pzText = strstr( pzText, ztitle );
+        pzText = strstr(pzText, ttl);
     } while (pzText != NULL);
 
+    free(ttl);
+    if (pzText != NULL)
+        for (;;) {
+            if (*pzText == NUL) {
+                pzText = NULL;
+                break;
+            }
+            if (*(pzText++) == '>')
+                break;
+        }
+
     return pzText;
 }
 
 
-/*  handleProgramSection
- *
+/**
  *  "pzText" points to a '[' character.
  *  The "traditional" [PROG_NAME] segmentation of the config file.
  *  Do not ever mix with the "<?program prog-name>" variation.
  */
-static char*
-handleProgramSection(
-    tOptions*     pOpts,
-    char*         pzText )
+static char *
+handle_section(tOptions * pOpts, char * pzText)
 {
-    size_t len = strlen( pOpts->pzPROGNAME );
-    if (   (strncmp( pzText+1, pOpts->pzPROGNAME, len ) == 0)
+    size_t len = strlen(pOpts->pzPROGNAME);
+    if (   (strncmp(pzText+1, pOpts->pzPROGNAME, len) == 0)
         && (pzText[len+1] == ']'))
-        return strchr( pzText + len + 2, '\n' );
+        return strchr(pzText + len + 2, '\n');
 
     if (len > 16)
         return NULL;
 
     {
         char z[24];
-        sprintf( z, "[%s]", pOpts->pzPROGNAME );
-        pzText = strstr( pzText, z );
+        sprintf(z, "[%s]", pOpts->pzPROGNAME);
+        pzText = strstr(pzText, z);
     }
 
     if (pzText != NULL)
-        pzText = strchr( pzText, '\n' );
+        pzText = strchr(pzText, '\n');
     return pzText;
 }
 
 
-/*  handleStructure
- *
+/**
  *  "pzText" points to a '<' character, followed by an alpha.
  *  The end of the entry is either the "/>" following the name, or else a
  *  "</name>" string.
  */
-static char*
-handleStructure(
-    tOptions*     pOpts,
-    tOptState*    pOS,
-    char*         pzText,
-    int           direction )
+static char *
+handle_struct(tOptions * pOpts, tOptState * pOS, char * pzText, int dir)
 {
     tOptionLoadMode mode = option_load_mode;
     tOptionValue    valu;
@@ -693,7 +730,7 @@ handleStructure(
     switch (*pzText) {
     case ' ':
     case '\t':
-        pzText = parseAttributes( pOpts, pzText, &mode, &valu );
+        pzText = parseAttributes(pOpts, pzText, &mode, &valu);
         if (*pzText == '>')
             break;
         if (*pzText != '/')
@@ -705,14 +742,14 @@ handleStructure(
             return NULL;
         *pzText = NUL;
         pzText += 2;
-        loadOptionLine( pOpts, pOS, pzName, direction, mode );
+        loadOptionLine(pOpts, pOS, pzName, dir, mode);
         return pzText;
 
     case '>':
         break;
 
     default:
-        pzText = strchr( pzText, '>');
+        pzText = strchr(pzText, '>');
         if (pzText != NULL)
             pzText++;
         return pzText;
@@ -734,9 +771,9 @@ handleStructure(
         if (len > sizeof(z))
             pz = AGALOC(len, "scan name");
 
-        sprintf( pz, "</%s>", pzName );
+        sprintf(pz, "</%s>", pzName);
         *pzText = ' ';
-        pzText = strstr( pzText, pz );
+        pzText = strstr(pzText, pz);
         if (pz != z) AGFREE(pz);
 
         if (pzText == NULL)
@@ -787,20 +824,19 @@ handleStructure(
      *  "pzName" points to what looks like text for one option/configurable.
      *  It is NUL terminated.  Process it.
      */
-    loadOptionLine( pOpts, pOS, pzName, direction, mode );
+    loadOptionLine(pOpts, pOS, pzName, dir, mode);
 
     return pzText;
 }
 
 
-/*  internalFileLoad
- *
+/**
  *  Load a configuration file.  This may be invoked either from
  *  scanning the "homerc" list, or from a specific file request.
  *  (see "optionFileLoad()", the implementation for --load-opts)
  */
 LOCAL void
-internalFileLoad( tOptions* pOpts )
+internalFileLoad(tOptions* pOpts)
 {
     uint32_t  svfl;
     int       idx;
@@ -851,8 +887,8 @@ internalFileLoad( tOptions* pOpts )
 
         idx += inc;
 
-        if (! optionMakePath( zFileName, (int)sizeof(zFileName),
-                              pzPath, pOpts->pzProgPath ))
+        if (! optionMakePath(zFileName, (int)sizeof(zFileName),
+                             pzPath, pOpts->pzProgPath))
             continue;
 
         /*
@@ -860,23 +896,23 @@ internalFileLoad( tOptions* pOpts )
          *  THEN append the Resource Configuration file name
          *  ELSE we must have the complete file name
          */
-        if (stat( zFileName, &StatBuf ) != 0)
+        if (stat(zFileName, &StatBuf) != 0)
             continue; /* bogus name - skip the home list entry */
 
-        if (S_ISDIR( StatBuf.st_mode )) {
-            size_t len = strlen( zFileName );
+        if (S_ISDIR(StatBuf.st_mode)) {
+            size_t len = strlen(zFileName);
             char* pz;
 
-            if (len + 1 + strlen( pOpts->pzRcName ) >= sizeof( zFileName ))
+            if (len + 1 + strlen(pOpts->pzRcName) >= sizeof(zFileName))
                 continue;
 
             pz = zFileName + len;
             if (pz[-1] != DIRCH)
                 *(pz++) = DIRCH;
-            strcpy( pz, pOpts->pzRcName );
+            strcpy(pz, pOpts->pzRcName);
         }
 
-        filePreset( pOpts, zFileName, inc );
+        file_preset(pOpts, zFileName, inc);
 
         /*
          *  IF we are now to skip config files AND we are presetting,
@@ -929,13 +965,13 @@ internalFileLoad( tOptions* pOpts )
  *       always be returned.
 =*/
 int
-optionFileLoad( tOptions* pOpts, char const* pzProgram )
+optionFileLoad(tOptions* pOpts, char const* pzProgram)
 {
-    if (! SUCCESSFUL( validateOptionsStruct( pOpts, pzProgram )))
+    if (! SUCCESSFUL(validateOptionsStruct(pOpts, pzProgram)))
         return -1;
 
     pOpts->pzProgName = pzProgram;
-    internalFileLoad( pOpts );
+    internalFileLoad(pOpts);
     return 0;
 }
 
@@ -952,7 +988,7 @@ optionFileLoad( tOptions* pOpts, char const* pzProgram )
  *  pOptDesc->optArg.argString.
 =*/
 void
-optionLoadOpt( tOptions* pOpts, tOptDesc* pOptDesc )
+optionLoadOpt(tOptions* pOpts, tOptDesc* pOptDesc)
 {
     struct stat sb;
 
@@ -966,31 +1002,30 @@ optionLoadOpt( tOptions* pOpts, tOptDesc* pOptDesc )
        || ((pOptDesc->fOptState & OPTST_RESET) != 0))
         return;
 
-    if (stat( pOptDesc->optArg.argString, &sb ) != 0) {
+    if (stat(pOptDesc->optArg.argString, &sb) != 0) {
         if ((pOpts->fOptSet & OPTPROC_ERRSTOP) == 0)
             return;
 
-        fprintf( stderr, zFSErrOptLoad, errno, strerror( errno ),
-                 pOptDesc->optArg.argString );
+        fprintf(stderr, zFSErrOptLoad, errno, strerror(errno),
+                pOptDesc->optArg.argString);
         exit(EX_NOINPUT);
         /* NOT REACHED */
     }
 
-    if (! S_ISREG( sb.st_mode )) {
+    if (! S_ISREG(sb.st_mode)) {
         if ((pOpts->fOptSet & OPTPROC_ERRSTOP) == 0)
             return;
 
-        fprintf( stderr, zNotFile, pOptDesc->optArg.argString );
+        fprintf(stderr, zNotFile, pOptDesc->optArg.argString);
         exit(EX_NOINPUT);
         /* NOT REACHED */
     }
 
-    filePreset(pOpts, pOptDesc->optArg.argString, DIRECTION_CALLED);
+    file_preset(pOpts, pOptDesc->optArg.argString, DIRECTION_CALLED);
 }
 
 
-/*  parseAttributes
- *
+/**
  *  Parse the various attributes of an XML-styled config file entry
  */
 LOCAL char*
@@ -1018,15 +1053,15 @@ parseAttributes(
 
         switch (find_xat_attribute_id(pzText, len)) {
         case XAT_KWD_TYPE:
-            pzText = parseValueType( pzText+len, pType );
+            pzText = parse_value(pzText+len, pType);
             break;
 
         case XAT_KWD_WORDS:
-            pzText = parseKeyWordType( pOpts, pzText+len, pType );
+            pzText = parse_keyword(pOpts, pzText+len, pType);
             break;
 
         case XAT_KWD_MEMBERS:
-            pzText = parseSetMemType( pOpts, pzText+len, pType );
+            pzText = parse_set_mem(pOpts, pzText+len, pType);
             break;
 
         case XAT_KWD_COOKED:
@@ -1057,7 +1092,7 @@ parseAttributes(
         case XAT_KWD_INVALID:
         invalid_kwd:
             pType->valType = OPARG_TYPE_NONE;
-            return skipUnknown( pzText );
+            return skip_unkn(pzText);
         }
     } while (pzText != NULL);
 
@@ -1065,45 +1100,34 @@ parseAttributes(
 }
 
 
-/*  parseKeyWordType
- *
+/**
  *  "pzText" points to the character after "words=".
  *  What should follow is a name of a keyword (enumeration) list.
  */
 static char*
-parseKeyWordType(
-    tOptions*     pOpts,
-    char*         pzText,
-    tOptionValue* pType )
+parse_keyword(tOptions * pOpts, char * pzText, tOptionValue * pType)
 {
-    return skipUnknown( pzText );
+    return skip_unkn(pzText);
 }
 
 
-/*  parseSetMemType
- *
+/**
  *  "pzText" points to the character after "members="
  *  What should follow is a name of a "set membership".
  *  A collection of bit flags.
  */
 static char*
-parseSetMemType(
-    tOptions*     pOpts,
-    char*         pzText,
-    tOptionValue* pType )
+parse_set_mem(tOptions * pOpts, char * pzText, tOptionValue * pType)
 {
-    return skipUnknown( pzText );
+    return skip_unkn(pzText);
 }
 
 
-/*  parseValueType
- *
+/**
  *  "pzText" points to the character after "type="
  */
-static char*
-parseValueType(
-    char*         pzText,
-    tOptionValue* pType )
+static char *
+parse_value(char * pzText, tOptionValue * pType)
 {
     size_t len = 0;
 
@@ -1116,7 +1140,7 @@ parseValueType(
     if ((len == 0) || (! IS_END_XML_TOKEN_CHAR(*pzText))) {
     woops:
         pType->valType = OPARG_TYPE_NONE;
-        return skipUnknown( pzText );
+        return skip_unkn(pzText);
     }
 
     switch (find_value_type_id(pzText - len, len)) {
@@ -1154,12 +1178,11 @@ parseValueType(
 }
 
 
-/*  skipUnknown
- *
+/**
  *  Skip over some unknown attribute
  */
-static char*
-skipUnknown( char* pzText )
+static char *
+skip_unkn(char* pzText)
 {
     for (;; pzText++) {
         if (IS_END_XML_TOKEN_CHAR(*pzText))  return pzText;
@@ -1168,8 +1191,7 @@ skipUnknown( char* pzText )
 }
 
 
-/*  validateOptionsStruct
- *
+/**
  *  Make sure the option descriptor is there and that we understand it.
  *  This should be called from any user entry point where one needs to
  *  worry about validity.  (Some entry points are free to assume that
@@ -1177,11 +1199,11 @@ skipUnknown( char* pzText )
  *  already been called.)
  */
 LOCAL tSuccess
-validateOptionsStruct( tOptions* pOpts, char const* pzProgram )
+validateOptionsStruct(tOptions* pOpts, char const* pzProgram)
 {
     if (pOpts == NULL) {
-        fputs( zAO_Bad, stderr );
-        exit( EX_CONFIG );
+        fputs(zAO_Bad, stderr);
+        exit(EX_CONFIG);
     }
 
     /*
@@ -1213,9 +1235,9 @@ validateOptionsStruct( tOptions* pOpts, char const* pzProgram )
 
         fprintf(stderr, zAO_Err, pzProgram, NUM_TO_VER(pOpts->structVersion));
         if (pOpts->structVersion > OPTIONS_STRUCT_VERSION )
-            fputs( zAO_Big, stderr );
+            fputs(zAO_Big, stderr);
         else
-            fputs( zAO_Sml, stderr );
+            fputs(zAO_Sml, stderr);
 
         return FAILURE;
     }
@@ -1225,7 +1247,7 @@ validateOptionsStruct( tOptions* pOpts, char const* pzProgram )
      *  and the set of equivalent characters.
      */
     if (pOpts->pzProgName == NULL) {
-        char const* pz = strrchr( pzProgram, DIRCH );
+        char const* pz = strrchr(pzProgram, DIRCH);
 
         if (pz == NULL)
              pOpts->pzProgName = pzProgram;
@@ -1236,7 +1258,7 @@ validateOptionsStruct( tOptions* pOpts, char const* pzProgram )
         /*
          *  when comparing long names, these are equivalent
          */
-        strequate( zSepChars );
+        strequate(zSepChars);
     }
 
     return SUCCESS;
